#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# Srain documentation build configuration file, created by
# sphinx-quickstart on Sun Jul 16 12:29:59 2017.
#
# This file is execfile()d with the current directory set to its
# containing dir.
#
# Note that not all possible configuration values are present in this
# autogenerated file.
#
# All configuration values have a default; values that are commented out
# serve to show the default.

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))

# -- Enviroment information -----------------------------------------------------

CI = os.environ.get('CI') is not None

# -- General configuration ------------------------------------------------

# If your documentation needs a minimal Sphinx version, state it here.
#
# needs_sphinx = '1.0'

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    'sphinx.ext.githubpages',
    'sphinx.ext.intersphinx',
]

# Add any paths that contain templates here, relative to this directory.
templates_path = ['.templates']

# The suffix(es) of source filenames.
# You can specify multiple suffix as a list of string:
#
# source_suffix = ['.rst', '.md']
source_suffix = '.rst'

# The master toctree document.
master_doc = 'index'

# General information about the project.
project = 'Srain'
copyright = '2024, Shengyu Zhang'
author = 'Shengyu Zhang'
baseurl = 'https://srain.silverrainz.me/'

# The version info for the project you're documenting, acts as replacement for
# |version| and |release|, also used in various other places throughout the
# built documents.
#
# The short X.Y version.
version = '1.8.1'
# The full version, including alpha/beta/rc tags.
release = version

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = 'en'

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This patterns also effect to html_static_path and html_extra_path
exclude_patterns = ['.build', 'Thumbs.db', '.DS_Store']

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = 'sphinx'

# A URL to cross-reference manpage directives.
manpages_url = 'https://man7.org/linux/man-pages/man{section}/{page}.{section}.html'

# -- Options for HTML output ----------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
# HTML theme configuration
if CI:
    html_theme = 'sphinx_book_theme'
else:
    html_theme = 'alabaster'

if CI:
    html_theme_options = {
        'repository_url': 'https://github.com/SrainApp/srain',
        "use_repository_button": True,
        "use_download_button": False,
        "show_toc_level": 2,
    }

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

html_css_files = []

html_baseurl = baseurl

# Custom sidebar templates, must be a dictionary that maps document names
# to template names.
#
if CI:
    blog_post_page = [ # Provided by sphinx_book_theme
                      'navbar-logo',
                      # Provided by ABlog
                      'ablog/postcard', 'ablog/recentposts', 'ablog/tagcloud',
                      'ablog/categories', 'ablog/archives']
    html_sidebars = {
        'blog': blog_post_page, # ABlog's "All Posts" page
        'blog/**': blog_post_page, # Inlucde posts and autogenerated pages
        'changelog': blog_post_page, # Inlucde posts and autogenerated pages
    }

html_logo = '../data/icons/hicolor/128x128/apps/im.srain.Srain.png'
html_favicon = html_logo

# -- Options for HTMLHelp output ------------------------------------------

# Output file base name for HTML help builder.
htmlhelp_basename = 'Sraindoc'


# -- Options for LaTeX output ---------------------------------------------

latex_elements = {
    # The paper size ('letterpaper' or 'a4paper').
    #
    # 'papersize': 'letterpaper',

    # The font size ('10pt', '11pt' or '12pt').
    #
    # 'pointsize': '10pt',

    # Additional stuff for the LaTeX preamble.
    #
    # 'preamble': '',

    # Latex figure (float) alignment
    #
    # 'figure_align': 'htbp',
}

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title,
#  author, documentclass [howto, manual, or own class]).
latex_documents = [
    (master_doc, 'Srain.tex', 'Srain Documentation',
     'Shengyu Zhang', 'manual'),
]


# -- Options for manual page output ---------------------------------------

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [
    (master_doc, 'srain', 'Srain Documentation',
     [author], 1)
]


# -- Options for Texinfo output -------------------------------------------

# Grouping the document tree into Texinfo files. List of tuples
# (source start file, target name, title, author,
#  dir menu entry, description, category)
texinfo_documents = [
    (master_doc, 'Srain', 'Srain Documentation',
     author, 'Srain', 'One line description of project.',
     'Miscellaneous'),
]

# -- Options for sphinx.ext.extlinks --------------------------------------

extensions.append('sphinx.ext.extlinks')
extensions.append('sphinxnotes.mock')
mock_directives = []
mock_directives.append('contents') # Theme has built-in local-toc, see html_theme
mock_directives.append('post') # Theme has built-in local-toc, see html_theme

extlinks = {
    'issue': ('https://github.com/SrainApp/srain/issues/%s', '#%s'),
    'pull': ('https://github.com/SrainApp/srain/pull/%s', '#%s'),
    'commit': ('https://github.com/SrainApp/srain/commit/%s', '%s'),

    'contrib-issue': ('https://github.com/SrainApp/contrib/issues/%s', 'contrib#%s'),
    'contrib-pull': ('https://github.com/SrainApp/contrib/pull/%s', 'contrib#%s'),
    'contrib-commit': ('https://github.com/SrainApp/srain/commit/%s', '%s'),

    'people': ('https://github.com/%s', '@%s'),
    'ghrepo': ('https://github.com/%s', '⛺ %s'),
}

if CI:
    extensions.append('sphinxnotes.strike')

    extensions.append('ablog')
    blog_path = 'blog'
    blog_title = project
    blog_baseurl = baseurl
    blog_date_format = '%Y-%m-%d'
    blog_authors = {
        author: (author, blog_baseurl),
    }
    blog_languages = {
        language: ('English',  None),
    }
    blog_default_author = author
    blog_default_language = language
    post_auto_image = 1
    blog_feed_fulltext = True
    fontawesome_included = True
    html_css_files.append('ablog-custom.css')

    extensions.append('sphinxnotes.mock')
    mock_directives = []
    mock_directives.append('contents') # Theme has built-in local-toc, see html_theme

    extensions.append('sphinx_sitemap')
    sitemap_filename = "sitemap.xml"
    sitemap_url_scheme = "{link}"

    extensions.append('sphinxcontrib.gtagjs')
    gtagjs_ids = ['G-6DC73T8933']

    extensions.append('sphinxext.opengraph')
    ogp_site_url = baseurl
    ogp_site_name = project



#!/usr/bin/python3
# A python script to upload the release assets via the GitHub Release API.
import mimetypes
import os
import requests
import sys

# Written for Github actions when release created event is triggered.
# It must set the env variables in the GitHub actions file:
#      env:
#        GH_TOKEN: ${{ secrets.GITHUB_TOKEN }}
#        GH_REPO: ${{ github.repository }}
#        GH_REF: ${{ github.ref }}
GithubToken = os.environ["GH_TOKEN"]
GithubRepository = os.environ["GH_REPO"]
GithubRef = os.environ["GH_REF"]
GithubTagname = GithubRef.replace(u'refs/tags/','')

# List releases for a repository:
# https://developer.github.com/v3/repos/releases/#list-releases-for-a-repository
releasesAPI = "https://api.github.com/repos/" + GithubRepository + "/releases"

# The hardcoded path of assets, eg. "out/".
outputFilePath = "out/"

def get_uploadurl():
  global uploadURL

  print("Releases API: " + releasesAPI)

  headers = {
    'Authorization': 'token ' + GithubToken,
  }

  response = requests.get(releasesAPI, headers=headers)

  print("API status code: " + str(response.status_code))

  releases = response.json()
  releasesLength = len(releases)

  for i in range (0, releasesLength):
    if releases[i]["tag_name"] == GithubTagname:
      releasesNumber = i
      break

  try:
    print("Found the target tagname, continue... " + str(releasesNumber))

  # In case the tag was deleted before this python script running.
  except Exception:
    print("Can't found the target tagname, exit.")
    sys.exit(1)

  uploadURL = releases[releasesNumber]["upload_url"].split(u"{")[0]

  print("Upload URL: " + uploadURL)

def upload_assets():
  outputFiles = os.listdir(outputFilePath)
  outputFilesNumber = len(outputFiles)
  print("Assets: " + str(outputFiles) + "\nAssets number: " + str(outputFilesNumber))

  ifFailure = False;

  for i in range (0, outputFilesNumber):
    filename = outputFiles[i]
    print("Current asset: " + filename)

    # Upload a release asset:
    # https://developer.github.com/v3/repos/releases/#upload-a-release-asset

    # `Content-Type` is required, use `mimetypes` to guess the file's mimetype.
    mimetype = mimetypes.guess_type(outputFilePath + filename)[0]

    # Use `application/octet-stream` for an unknown filetype.
    if mimetype is None:
      mimetype = "application/octet-stream"

    print("Mimetype: " + mimetype)

    headers = {
      'Authorization': 'token ' + GithubToken,
      'Content-Type': mimetype,
    }

    params = (('name', filename),)

    data = open(outputFilePath + filename, 'rb').read();

    response = requests.post(uploadURL, headers=headers, params=params, data=data)

    # For debugging.
    print("API status code: " + str(response.status_code))
    #print("API response:\n" + str(response.text))

    # Response for successful upload: 201 Created
    # https://developer.github.com/v3/repos/releases/#response-for-successful-upload
    if response.status_code == 201:
      print("Asset download url: " + response.json()["browser_download_url"])
      print(
        "\033[1;32;40m["
        + str(i + 1)
        + "/"
        + str(outputFilesNumber)
        + "]"
        + filename
        + ": success. "
        + "\033[0m"
      )

    else:
      print(
        "\033[1;31;40m["
        + str(i + 1)
        + "/"
        + str(outputFilesNumber)
        + "]"
        + filename
        + ": fail. "
        + "\033[0m"
      )
      ifFailure = True

  if ifFailure == True:
    sys.exit(1)

  elif ifFailure == False:
    sys.exit(0)

if __name__ == '__main__':
  get_uploadurl()
  upload_assets()